{ config, pkgs, ... }:

{
  # https://github.com/danieldk/nix-home/blob/master/home/cfg/desktop.nix
  # https://github.com/Martins3/My-Linux-Config/blob/master/nixpkgs/home/app/gnome.nix

  # gsettings (or dconf-editor) schemas are spread throughout the nix store.
  # One can use a script to add them to $XDG_DATA_DIRS and then execute a command.
  # Here is an example script:
  # https://github.com/NixOS/nixpkgs/issues/33277#issuecomment-354689755

  programs.dconf.enable = true;

  home-manager.users.yoda = { osConfig, config, pkgs, ... }: {
    dconf.settings = {
      "org/gnome/desktop/media-handling" = {
        # Settings > Removable Media > Never promt or start apps on media insertion
        autorun-never = true;
      };

      "org/gnome/settings-daemon/plugins/power" = {
        # Settings > Automatic Suspend > Plugged In
        sleep-inactive-ac-type = "nothing";
        # Settings > Automatic Suspend > On Battery Power
        sleep-inactive-battery-type = "suspend";
      };

      "org/gnome/desktop/privacy" = {
        # Settings > File History > Enabled
        remember-recent-files = true;
        # Settings > File History > File History Duration
        recent-files-max-age = 30;

        # Settings > Trash and Temporary Files > Automatically Delete Trash Content
        remove-old-trash-files = true;
        # Settings > Trash and Temporary Files > Automatically Delete Temporary Files
        remove-old-temp-files = true;
        # Settings > Trash and Temporary Files > Automatically Delete Period
        old-files-age = 30;
      };

      "org/gnome/settings-daemon/plugins/color" = {
        night-light-enabled = true;
        night-light-schedule-automatic = false;
        #night-light-temperature = "uint32 3700";
      };

      "org/gnome/mutter" = {
        dynamic-workspaces = true;
        workspaces-only-on-primary = true;
      };

      "org/gnome/desktop/interface" = {
        # Dark Style
        color-scheme = "prefer-dark";
        # Multitasking > General > Hot Corner
        enable-hot-corners = false;
        show-battery-percentage = true;
      };
    };
  };
}
